@@ -33,7 +33,7 @@ static void dump_data(VALUE obj, int depth, Out out, bool as_ok) {
         if (oj_bigdecimal_class == clas) {
             volatile VALUE rstr = oj_safe_string_convert(obj);
             const char    *str  = RSTRING_PTR(rstr);
-            int            len  = (int)RSTRING_LEN(rstr);
+            size_t         len  = RSTRING_LEN(rstr);
 
             if (No != out->opts->bigdec_as_num) {
                 oj_dump_raw(str, len, out);
@@ -62,7 +62,7 @@ static void dump_obj(VALUE obj, int depth, Out out, bool as_ok) {
     if (oj_bigdecimal_class == clas) {
         volatile VALUE rstr = oj_safe_string_convert(obj);
         const char    *str  = RSTRING_PTR(rstr);
-        int            len  = (int)RSTRING_LEN(rstr);
+        size_t         len  = RSTRING_LEN(rstr);
 
         if (0 == strcasecmp("Infinity", str)) {
             str = oj_nan_str(obj, out->opts->dump_opts.nan_dump, out->opts->mode, true, &len);
@@ -95,7 +95,8 @@ static void dump_class(VALUE obj, int depth, Out out, bool as_ok) {
 
 static void dump_array_class(VALUE a, VALUE clas, int depth, Out out) {
     size_t size;
-    int    i, cnt;
+    size_t i;
+    size_t cnt;
     int    d2 = depth + 1;
     long   id = oj_check_circular(a, out);
 
@@ -106,7 +107,7 @@ static void dump_array_class(VALUE a, VALUE clas, int depth, Out out) {
         dump_obj_attrs(a, clas, 0, depth, out);
         return;
     }
-    cnt         = (int)RARRAY_LEN(a);
+    cnt         = RARRAY_LEN(a);
     *out->cur++ = '[';
     if (0 < id) {
         assure_size(out, d2 * out->indent + 16);
@@ -181,7 +182,7 @@ static void dump_str_class(VALUE obj, VALUE clas, int depth, Out out) {
         dump_obj_attrs(obj, clas, 0, depth, out);
     } else {
         const char *s   = RSTRING_PTR(obj);
-        size_t      len = (int)RSTRING_LEN(obj);
+        size_t      len = RSTRING_LEN(obj);
         char        s1  = s[1];
 
         oj_dump_cstr(s, len, 0, (':' == *s || ('^' == *s && ('r' == s1 || 'i' == s1))), out);
@@ -195,7 +196,7 @@ static void dump_str(VALUE obj, int depth, Out out, bool as_ok) {
 static void dump_sym(VALUE obj, int depth, Out out, bool as_ok) {
     volatile VALUE s = rb_sym2str(obj);
 
-    oj_dump_cstr(RSTRING_PTR(s), (int)RSTRING_LEN(s), 1, 0, out);
+    oj_dump_cstr(RSTRING_PTR(s), RSTRING_LEN(s), 1, 0, out);
 }
 
 static int hash_cb(VALUE key, VALUE value, VALUE ov) {
@@ -389,7 +390,7 @@ static void dump_odd(VALUE obj, Odd odd, VALUE clas, int depth, Out out) {
             rb_raise(rb_eEncodingError, "Invalid type for raw JSON.");
         } else {
             const char *s    = RSTRING_PTR(v);
-            int         len  = (int)RSTRING_LEN(v);
+            size_t      len  = RSTRING_LEN(v);
             const char *name = rb_id2name(*odd->attrs);
             size_t      nlen = strlen(name);
 
@@ -489,7 +490,7 @@ static void dump_obj_attrs(VALUE obj, VALUE clas, slot_t id, int depth, Out out)
         *out->cur++ = ',';
         fill_indent(out, d2);
         APPEND_CHARS(out->cur, "\"self\":", 7);
-        oj_dump_cstr(RSTRING_PTR(obj), (int)RSTRING_LEN(obj), 0, 0, out);
+        oj_dump_cstr(RSTRING_PTR(obj), RSTRING_LEN(obj), 0, 0, out);
         break;
     case T_ARRAY:
         assure_size(out, d2 * out->indent + 14);
@@ -564,11 +565,12 @@ static void dump_regexp(VALUE obj, int depth, Out out, bool as_ok) {
 static void dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
     VALUE       clas       = rb_obj_class(obj);
     const char *class_name = rb_class2name(clas);
-    int         i;
-    int         d2   = depth + 1;
-    int         d3   = d2 + 1;
-    size_t      len  = strlen(class_name);
-    size_t      size = d2 * out->indent + d3 * out->indent + 10 + len;
+    size_t      i;
+    int         d2       = depth + 1;
+    int         d3       = d2 + 1;
+    size_t      len      = strlen(class_name);
+    size_t      size     = d2 * out->indent + d3 * out->indent + 10 + len;
+    char        circular = out->opts->circular;
 
     assure_size(out, size);
     *out->cur++ = '{';
@@ -577,14 +579,14 @@ static void dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
     if ('#' == *class_name) {
         VALUE       ma = rb_struct_s_members(clas);
         const char *name;
-        int         cnt = (int)RARRAY_LEN(ma);
+        size_t      cnt = RARRAY_LEN(ma);
 
         *out->cur++ = '[';
         for (i = 0; i < cnt; i++) {
             volatile VALUE s = rb_sym2str(RARRAY_AREF(ma, i));
 
             name = RSTRING_PTR(s);
-            len  = (int)RSTRING_LEN(s);
+            len  = RSTRING_LEN(s);
             size = len + 3;
             assure_size(out, size);
             if (0 < i) {
@@ -607,14 +609,18 @@ static void dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
     {
         VALUE v;
         int   cnt;
+
 #if RSTRUCT_LEN_RETURNS_INTEGER_OBJECT
         cnt = (int)NUM2LONG(RSTRUCT_LEN(obj));
 #else   // RSTRUCT_LEN_RETURNS_INTEGER_OBJECT
         cnt = (int)RSTRUCT_LEN(obj);
 #endif  // RSTRUCT_LEN_RETURNS_INTEGER_OBJECT
 
-        for (i = 0; i < cnt; i++) {
-            v = RSTRUCT_GET(obj, i);
+        if (0 == strcmp(class_name, "Range")) {
+            out->opts->circular = 'n';
+        }
+        for (i = 0; i < (size_t)cnt; i++) {
+            v = RSTRUCT_GET(obj, (int)i);
             if (dump_ignore(out->opts, v)) {
                 v = Qnil;
             }
@@ -630,6 +636,9 @@ static void dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
         // class in interpreted Ruby so length() may not be defined.
         int slen = FIX2INT(rb_funcall2(obj, oj_length_id, 0, 0));
 
+        if (0 == strcmp(class_name, "Range")) {
+            out->opts->circular = 'n';
+        }
         for (i = 0; i < slen; i++) {
             assure_size(out, size);
             fill_indent(out, d3);
@@ -641,6 +650,7 @@ static void dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
         }
     }
 #endif
+    out->opts->circular = circular;
     out->cur--;
     APPEND_CHARS(out->cur, "]}", 2);
     *out->cur = '\0';
