@@ -39,11 +39,7 @@ void _oj_err_set_with_location(Err         err,
     oj_err_set(err, eclas, "%s at line %d, column %d [%s:%d]", msg, n, col, file, line);
 }
 
-void _oj_raise_error(const char *msg,
-                     const char *json,
-                     const char *current,
-                     const char *file,
-                     int         line) {
+void _oj_raise_error(const char *msg, const char *json, const char *current, const char *file, int line) {
     struct _err err;
     int         n   = 1;
     int         col = 1;
@@ -56,13 +52,6 @@ void _oj_raise_error(const char *msg,
             n++;
         }
     }
-    oj_err_set(&err,
-               oj_parse_error_class,
-               "%s at line %d, column %d [%s:%d]",
-               msg,
-               n,
-               col,
-               file,
-               line);
+    oj_err_set(&err, oj_parse_error_class, "%s at line %d, column %d [%s:%d]", msg, n, col, file, line);
     rb_raise(err.clas, "%s", err.msg);
 }
