@@ -1114,9 +1114,6 @@ static void parse(ojParser p, const byte *json) {
             p->map = trail_map;
         }
     }
-    if (0 < p->depth) {
-        parse_error(p, "parse error, not closed");
-    }
     if (0 == p->depth) {
         switch (p->map[256]) {
         case '0':
@@ -1164,7 +1161,7 @@ static void parser_mark(void *ptr) {
     }
 }
 
-static const rb_data_type_t oj_parser_type = {
+const rb_data_type_t oj_parser_type = {
     "Oj/parser",
     {
         parser_mark,
@@ -1394,6 +1391,12 @@ static VALUE load(VALUE self) {
         if (0 < RSTRING_LEN(rbuf)) {
             parse(p, (byte *)StringValuePtr(rbuf));
         }
+        if (Qtrue == rb_funcall(p->reader, oj_eofq_id, 0)) {
+            if (0 < p->depth) {
+                parse_error(p, "parse error, not closed");
+            }
+            break;
+        }
     }
     return Qtrue;
 }
