@@ -469,22 +469,20 @@ static VALUE str_writer_reset(VALUE self) {
 static VALUE str_writer_to_s(VALUE self) {
     StrWriter sw;
     TypedData_Get_Struct(self, struct _strWriter, &oj_string_writer_type, sw);
-    VALUE rstr = rb_str_new(sw->out.buf, sw->out.cur - sw->out.buf);
-
-    return oj_encode(rstr);
+    return rb_utf8_str_new(sw->out.buf, sw->out.cur - sw->out.buf);
 }
 
 /* Document-method: as_json
- * call-seq: as_json()
+ * call-seq: as_json(*)
  *
  * Returns the contents of the writer as a JSON element. If called from inside
  * an array or hash by Oj the raw buffer will be used othersize a more
  * inefficient parse of the contents and a return of the result is
- * completed. The parse uses the strict mode.
+ * completed. The parse uses the strict mode. Optional arguments are ignored.
  *
  * *return* [_Hash_|_Array_|_String_|_Integer_|_Float_|_True_|_False_|_nil|)
  */
-static VALUE str_writer_as_json(VALUE self) {
+static VALUE str_writer_as_json(int argc, VALUE *argv, VALUE self) {
     if (string_writer_optimized) {
         return self;
     }
@@ -515,5 +513,5 @@ void oj_string_writer_init(void) {
     rb_define_method(oj_string_writer_class, "reset", str_writer_reset, 0);
     rb_define_method(oj_string_writer_class, "to_s", str_writer_to_s, 0);
     rb_define_method(oj_string_writer_class, "raw_json", str_writer_to_s, 0);
-    rb_define_method(oj_string_writer_class, "as_json", str_writer_as_json, 0);
+    rb_define_method(oj_string_writer_class, "as_json", str_writer_as_json, -1);
 }
