@@ -1,23 +1,24 @@
 #!/usr/bin/env ruby
-# encoding: UTF-8
+# frozen_string_literal: true
 
-$: << '.'
-$: << File.join(File.dirname(__FILE__), "../lib")
-$: << File.join(File.dirname(__FILE__), "../ext")
+require 'English'
+$LOAD_PATH << '.'
+$LOAD_PATH << File.join(__dir__, '../lib')
+$LOAD_PATH << File.join(__dir__, '../ext')
 
 require 'oj'
 
 filename = 'tmp.json'
-File.open(filename, "w") { |f|
+File.open(filename, 'w') { |f|
   cnt = 0
   f.puts('{')
   ('a'..'z').each { |a|
     ('a'..'z').each { |b|
       ('a'..'z').each { |c|
-	('a'..'z').each { |d|
-	  f.puts(%|"#{a}#{b}#{c}#{d}":#{cnt},|)
-	  cnt += 1
-	}
+        ('a'..'z').each { |d|
+          f.puts(%|"#{a}#{b}#{c}#{d}":#{cnt},|)
+          cnt += 1
+        }
       }
     }
   }
@@ -25,7 +26,7 @@ File.open(filename, "w") { |f|
 }
 
 def mem
-  `ps -o rss= -p #{$$}`.to_i
+  `ps -o rss= -p #{$PROCESS_ID}`.to_i
 end
 
 Oj.default_options = { mode: :strict, cache_keys: false, cache_str: -1 }
@@ -48,7 +49,7 @@ dur = Time.now - start
 GC.start
 puts "second cache duration: #{dur} @ #{mem}"
 
-10.times{ GC.start }
+10.times { GC.start }
 start = Time.now
 Oj.load_file('tmp.json')
 dur = Time.now - start
