@@ -1,8 +1,7 @@
 #!/usr/bin/env ruby
-# coding: utf-8
 # frozen_string_literal: true
 
-$: << File.dirname(__FILE__)
+$LOAD_PATH << __dir__
 
 require 'helper'
 
@@ -52,7 +51,7 @@ class DocTest < Minitest::Test
     json = %{true}
     Oj::Doc.open(json) do |doc|
       assert_equal(TrueClass, doc.type)
-      assert_equal(true, doc.fetch())
+      assert(doc.fetch())
     end
   end
 
@@ -60,7 +59,7 @@ class DocTest < Minitest::Test
     json = %{false}
     Oj::Doc.open(json) do |doc|
       assert_equal(FalseClass, doc.type)
-      assert_equal(false, doc.fetch())
+      refute(doc.fetch())
     end
   end
 
@@ -76,7 +75,7 @@ class DocTest < Minitest::Test
     json = %{"ぴーたー"}
     Oj::Doc.open(json) do |doc|
       assert_equal(String, doc.type)
-      assert_equal("ぴーたー", doc.fetch())
+      assert_equal('ぴーたー', doc.fetch())
     end
   end
 
@@ -84,19 +83,15 @@ class DocTest < Minitest::Test
     json = %{"\\u3074\\u30fc\\u305f\\u30fc"}
     Oj::Doc.open(json) do |doc|
       assert_equal(String, doc.type)
-      assert_equal("ぴーたー", doc.fetch())
+      assert_equal('ぴーたー', doc.fetch())
     end
   end
 
   def test_fixnum
     json = %{12345}
     Oj::Doc.open(json) do |doc|
-      if '2.4.0' <= RUBY_VERSION
-        assert_equal(Integer, doc.type)
-      else
-        assert_equal(Fixnum, doc.type)
-      end
-      assert_equal(12345, doc.fetch())
+      assert_equal(Integer, doc.type)
+      assert_equal(12_345, doc.fetch())
     end
   end
 
@@ -104,7 +99,7 @@ class DocTest < Minitest::Test
     json = %{12345.6789}
     Oj::Doc.open(json) do |doc|
       assert_equal(Float, doc.type)
-      assert_equal(12345.6789, doc.fetch())
+      assert_in_delta(12_345.6789, doc.fetch())
     end
   end
 
@@ -112,8 +107,8 @@ class DocTest < Minitest::Test
     json = %{12345.6789e7}
     Oj::Doc.open(json) do |doc|
       assert_equal(Float, doc.type)
-      #assert_equal(12345.6789e7, doc.fetch())
-      assert_equal(12345.6789e7.to_i, doc.fetch().to_i)
+      # assert_equal(12345.6789e7, doc.fetch())
+      assert_equal(12_345.6789e7.to_i, doc.fetch().to_i)
     end
   end
 
@@ -121,7 +116,7 @@ class DocTest < Minitest::Test
     json = %{[]}
     Oj::Doc.open(json) do |doc|
       assert_equal(Array, doc.type)
-      assert_equal([], doc.fetch())
+      assert_empty(doc.fetch())
     end
   end
 
@@ -137,7 +132,7 @@ class DocTest < Minitest::Test
     json = %{{}}
     Oj::Doc.open(json) do |doc|
       assert_equal(Hash, doc.type)
-      assert_equal({}, doc.fetch())
+      assert_empty(doc.fetch())
     end
   end
 
@@ -172,7 +167,8 @@ class DocTest < Minitest::Test
 
   def test_move
     Oj::Doc.open(@json1) do |doc|
-      [ '/',
+      [
+        '/',
         '/array',
         '/boolean',
         '/array/1/hash/h2/a/3',
@@ -205,13 +201,14 @@ class DocTest < Minitest::Test
 
   def test_move_relative
     Oj::Doc.open(@json1) do |doc|
-      [['/', 'array', '/array'],
-       ['/array', '1/num', '/array/1/num'],
-       ['/array/1/hash', 'h2/a', '/array/1/hash/h2/a'],
-       ['/array/1', 'hash/h2/a/2', '/array/1/hash/h2/a/2'],
-       ['/array/1/hash', '../string', '/array/1/string'],
-       ['/array/1/hash', '..', '/array/1'],
-      ].each do |start,path,where|
+      [
+        ['/', 'array', '/array'],
+        ['/array', '1/num', '/array/1/num'],
+        ['/array/1/hash', 'h2/a', '/array/1/hash/h2/a'],
+        ['/array/1', 'hash/h2/a/2', '/array/1/hash/h2/a/2'],
+        ['/array/1/hash', '../string', '/array/1/string'],
+        ['/array/1/hash', '..', '/array/1'],
+      ].each do |start, path, where|
         doc.move(start)
         doc.move(path)
         assert_equal(where, doc.where?)
@@ -220,21 +217,17 @@ class DocTest < Minitest::Test
   end
 
   def test_type
-    if '2.4.0' <= RUBY_VERSION
-      num_class = Integer
-    else
-      num_class = Fixnum
-    end
     Oj::Doc.open(@json1) do |doc|
-      [['/', Hash],
-       ['/array', Array],
-       ['/array/1', Hash],
-       ['/array/1/num', num_class],
-       ['/array/1/string', String],
-       ['/array/1/hash/h2/a', Array],
-       ['/array/1/hash/../num', num_class],
-       ['/array/1/hash/../..', Array],
-      ].each do |path,type|
+      [
+        ['/', Hash],
+        ['/array', Array],
+        ['/array/1', Hash],
+        ['/array/1/num', Integer],
+        ['/array/1/string', String],
+        ['/array/1/hash/h2/a', Array],
+        ['/array/1/hash/../num', Integer],
+        ['/array/1/hash/../..', Array],
+      ].each do |path, type|
         assert_equal(type, doc.type(path))
       end
     end
@@ -242,16 +235,17 @@ class DocTest < Minitest::Test
 
   def test_local_key
     Oj::Doc.open(@json1) do |doc|
-      [['/', nil],
-       ['/array', 'array'],
-       ['/array/1', 1],
-       ['/array/1/num', 'num'],
-       ['/array/1/string', 'string'],
-       ['/array/1/hash/h2/a', 'a'],
-       ['/array/1/hash/../num', 'num'],
-       ['/array/1/hash/..', 1],
-       ['/array/1/hash/../..', 'array'],
-      ].each do |path,key|
+      [
+        ['/', nil],
+        ['/array', 'array'],
+        ['/array/1', 1],
+        ['/array/1/num', 'num'],
+        ['/array/1/string', 'string'],
+        ['/array/1/hash/h2/a', 'a'],
+        ['/array/1/hash/../num', 'num'],
+        ['/array/1/hash/..', 1],
+        ['/array/1/hash/../..', 'array'],
+      ].each do |path, key|
         doc.move(path)
         if key.nil?
           assert_nil(doc.local_key())
@@ -264,16 +258,17 @@ class DocTest < Minitest::Test
 
   def test_fetch_move
     Oj::Doc.open(@json1) do |doc|
-      [['/array/1/num', 3],
-       ['/array/1/string', 'message'],
-       ['/array/1/hash/h2/a', [1, 2, 3]],
-       ['/array/1/hash/../num', 3],
-       ['/array/1/hash/..', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
-       ['/array/1/hash/../..', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
-       ['/array/1', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
-       ['/array', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
-       ['/', {'array' => [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}], 'boolean' => true}],
-      ].each do |path,val|
+      [
+        ['/array/1/num', 3],
+        ['/array/1/string', 'message'],
+        ['/array/1/hash/h2/a', [1, 2, 3]],
+        ['/array/1/hash/../num', 3],
+        ['/array/1/hash/..', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
+        ['/array/1/hash/../..', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
+        ['/array/1', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
+        ['/array', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
+        ['/', {'array' => [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}], 'boolean' => true}],
+      ].each do |path, val|
         doc.move(path)
         assert_equal(val, doc.fetch())
       end
@@ -282,18 +277,19 @@ class DocTest < Minitest::Test
 
   def test_fetch_path
     Oj::Doc.open(@json1) do |doc|
-      [['/array/1/num', 3],
-       ['/array/1/string', 'message'],
-       ['/array/1/hash/h2/a', [1, 2, 3]],
-       ['/array/1/hash/../num', 3],
-       ['/array/1/hash/..', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
-       ['/array/1/hash/../..', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
-       ['/array/1', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
-       ['/array', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
-       ['/', {'array' => [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}], 'boolean' => true}],
-       ['/nothing', nil],
-       ['/array/10', nil],
-      ].each do |path,val|
+      [
+        ['/array/1/num', 3],
+        ['/array/1/string', 'message'],
+        ['/array/1/hash/h2/a', [1, 2, 3]],
+        ['/array/1/hash/../num', 3],
+        ['/array/1/hash/..', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
+        ['/array/1/hash/../..', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
+        ['/array/1', {'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}],
+        ['/array', [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}]],
+        ['/', {'array' => [{'num' => 3, 'string' => 'message', 'hash' => {'h2' => {'a' => [1, 2, 3]}}}], 'boolean' => true}],
+        ['/nothing', nil],
+        ['/array/10', nil],
+      ].each do |path, val|
         if val.nil?
           assert_nil(doc.fetch(path))
         else
@@ -310,15 +306,15 @@ class DocTest < Minitest::Test
       assert_nil(doc.fetch('/x'))
       assert_nil(doc.fetch('/0'))
     end
-
   end
 
   def test_move_fetch_path
     Oj::Doc.open(@json1) do |doc|
-      [['/array/1', 'num', 3],
-       ['/array/1', 'string', 'message'],
-       ['/array/1/hash', 'h2/a', [1, 2, 3]],
-      ].each do |path,fetch_path,val|
+      [
+        ['/array/1', 'num', 3],
+        ['/array/1', 'string', 'message'],
+        ['/array/1/hash', 'h2/a', [1, 2, 3]],
+      ].each do |path, fetch_path, val|
         doc.move(path)
         assert_equal(val, doc.fetch(fetch_path))
       end
@@ -327,13 +323,14 @@ class DocTest < Minitest::Test
 
   def test_exists
     Oj::Doc.open(@json1) do |doc|
-      [['/array/1', true],
-       ['/array/1', true],
-       ['/array/1/hash', true],
-       ['/array/1/dash', false],
-       ['/array/3', false],
-       ['/nothing', false],
-      ].each do |path,val|
+      [
+        ['/array/1', true],
+        ['/array/1', true],
+        ['/array/1/hash', true],
+        ['/array/1/dash', false],
+        ['/array/3', false],
+        ['/nothing', false],
+      ].each do |path, val|
         assert_equal(val, doc.exists?(path), "failed for #{path.inspect}")
       end
     end
@@ -406,7 +403,7 @@ class DocTest < Minitest::Test
         end
       end
     end
-    assert_equal({"/a"=>1, "/c"=>[2], "/c/1"=>2, "/d"=>3}, h)
+    assert_equal({'/a'=>1, '/c'=>[2], '/c/1'=>2, '/d'=>3}, h)
   end
 
   def test_size
@@ -419,8 +416,8 @@ class DocTest < Minitest::Test
   end
 
   def test_open_file
-    filename = File.join(File.dirname(__FILE__), 'open_file_test.json')
-    File.open(filename, 'w') { |f| f.write('{"a":[1,2,3]}') }
+    filename = File.join(__dir__, 'open_file_test.json')
+    File.write(filename, '{"a":[1,2,3]}')
     Oj::Doc.open_file(filename) do |doc|
       assert_equal(5, doc.size)
     end
@@ -445,8 +442,8 @@ class DocTest < Minitest::Test
   end
 
   def test_file_open_close
-    filename = File.join(File.dirname(__FILE__), 'open_file_test.json')
-    File.open(filename, 'w') { |f| f.write('{"a":[1,2,3]}') }
+    filename = File.join(__dir__, 'open_file_test.json')
+    File.write(filename, '{"a":[1,2,3]}')
     doc = Oj::Doc.open_file(filename)
     assert_equal(Oj::Doc, doc.class)
     assert_equal(5, doc.size)
@@ -473,7 +470,6 @@ class DocTest < Minitest::Test
     doc.home()
     assert_equal(2, doc.fetch('/a/2'))
     assert_equal(2, doc.fetch('a/2'))
-    doc = nil
     GC.start
     # a print statement confirms close is called
   end
@@ -506,7 +502,7 @@ class DocTest < Minitest::Test
   end
 
   def test_doc_empty
-    result = Oj::Doc.open("") { |doc| doc.each_child {} }
+    result = Oj::Doc.open('') { |doc| doc.each_child {} }
     assert_nil(result)
   end
 
