@@ -1,11 +1,11 @@
 #!/usr/bin/env ruby
-# encoding: UTF-8
+# frozen_string_literal: true
 
-$: << File.dirname(__FILE__)
+$LOAD_PATH << __dir__
 
 require 'helper'
 
-class Hashi < Minitest::Test
+class HashTest < Minitest::Test
 
   module TestModule
   end
@@ -19,11 +19,21 @@ class Hashi < Minitest::Test
 
   def test_load
     obj = Oj.load(%|{"abc":3}|, :mode => :compat, :hash_class => Oj::EasyHash)
-    
+
     assert_equal(Oj::EasyHash, obj.class)
     assert_equal(3, obj['abc'])
     assert_equal(3, obj[:abc])
     assert_equal(3, obj.abc())
   end
-  
+
+  def test_marshal
+    h = Oj::EasyHash.new()
+    h['abc'] = 3
+    out = Marshal.dump(h)
+
+    obj = Marshal.load(out)
+    assert_equal(Oj::EasyHash, obj.class)
+    assert_equal(3, obj[:abc])
+  end
+
 end # HashTest
